{-# LANGUAGE DeriveGeneric #-}
{-# LANGUAGE DuplicateRecordFields #-}
{-# LANGUAGE NamedFieldPuns #-}
{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE RecordWildCards #-}
{-# LANGUAGE StrictData #-}
{-# LANGUAGE TypeFamilies #-}
{-# LANGUAGE NoImplicitPrelude #-}
{-# OPTIONS_GHC -fno-warn-unused-binds #-}
{-# OPTIONS_GHC -fno-warn-unused-imports #-}
{-# OPTIONS_GHC -fno-warn-unused-matches #-}

-- Derived from AWS service descriptions, licensed under Apache 2.0.

-- |
-- Module      : Amazonka.Route53.DeleteTrafficPolicyInstance
-- Copyright   : (c) 2013-2023 Brendan Hay
-- License     : Mozilla Public License, v. 2.0.
-- Maintainer  : Brendan Hay
-- Stability   : auto-generated
-- Portability : non-portable (GHC extensions)
--
-- Deletes a traffic policy instance and all of the resource record sets
-- that Amazon Route 53 created when you created the instance.
--
-- In the Route 53 console, traffic policy instances are known as policy
-- records.
module Amazonka.Route53.DeleteTrafficPolicyInstance
  ( -- * Creating a Request
    DeleteTrafficPolicyInstance (..),
    newDeleteTrafficPolicyInstance,

    -- * Request Lenses
    deleteTrafficPolicyInstance_id,

    -- * Destructuring the Response
    DeleteTrafficPolicyInstanceResponse (..),
    newDeleteTrafficPolicyInstanceResponse,

    -- * Response Lenses
    deleteTrafficPolicyInstanceResponse_httpStatus,
  )
where

import qualified Amazonka.Core as Core
import qualified Amazonka.Core.Lens.Internal as Lens
import qualified Amazonka.Data as Data
import qualified Amazonka.Prelude as Prelude
import qualified Amazonka.Request as Request
import qualified Amazonka.Response as Response
import Amazonka.Route53.Types

-- | A request to delete a specified traffic policy instance.
--
-- /See:/ 'newDeleteTrafficPolicyInstance' smart constructor.
data DeleteTrafficPolicyInstance = DeleteTrafficPolicyInstance'
  { -- | The ID of the traffic policy instance that you want to delete.
    --
    -- When you delete a traffic policy instance, Amazon Route 53 also deletes
    -- all of the resource record sets that were created when you created the
    -- traffic policy instance.
    id :: Prelude.Text
  }
  deriving (Prelude.Eq, Prelude.Read, Prelude.Show, Prelude.Generic)

-- |
-- Create a value of 'DeleteTrafficPolicyInstance' with all optional fields omitted.
--
-- Use <https://hackage.haskell.org/package/generic-lens generic-lens> or <https://hackage.haskell.org/package/optics optics> to modify other optional fields.
--
-- The following record fields are available, with the corresponding lenses provided
-- for backwards compatibility:
--
-- 'id', 'deleteTrafficPolicyInstance_id' - The ID of the traffic policy instance that you want to delete.
--
-- When you delete a traffic policy instance, Amazon Route 53 also deletes
-- all of the resource record sets that were created when you created the
-- traffic policy instance.
newDeleteTrafficPolicyInstance ::
  -- | 'id'
  Prelude.Text ->
  DeleteTrafficPolicyInstance
newDeleteTrafficPolicyInstance pId_ =
  DeleteTrafficPolicyInstance' {id = pId_}

-- | The ID of the traffic policy instance that you want to delete.
--
-- When you delete a traffic policy instance, Amazon Route 53 also deletes
-- all of the resource record sets that were created when you created the
-- traffic policy instance.
deleteTrafficPolicyInstance_id :: Lens.Lens' DeleteTrafficPolicyInstance Prelude.Text
deleteTrafficPolicyInstance_id = Lens.lens (\DeleteTrafficPolicyInstance' {id} -> id) (\s@DeleteTrafficPolicyInstance' {} a -> s {id = a} :: DeleteTrafficPolicyInstance)

instance Core.AWSRequest DeleteTrafficPolicyInstance where
  type
    AWSResponse DeleteTrafficPolicyInstance =
      DeleteTrafficPolicyInstanceResponse
  request overrides =
    Request.delete (overrides defaultService)
  response =
    Response.receiveEmpty
      ( \s h x ->
          DeleteTrafficPolicyInstanceResponse'
            Prelude.<$> (Prelude.pure (Prelude.fromEnum s))
      )

instance Prelude.Hashable DeleteTrafficPolicyInstance where
  hashWithSalt _salt DeleteTrafficPolicyInstance' {..} =
    _salt `Prelude.hashWithSalt` id

instance Prelude.NFData DeleteTrafficPolicyInstance where
  rnf DeleteTrafficPolicyInstance' {..} = Prelude.rnf id

instance Data.ToHeaders DeleteTrafficPolicyInstance where
  toHeaders = Prelude.const Prelude.mempty

instance Data.ToPath DeleteTrafficPolicyInstance where
  toPath DeleteTrafficPolicyInstance' {..} =
    Prelude.mconcat
      ["/2013-04-01/trafficpolicyinstance/", Data.toBS id]

instance Data.ToQuery DeleteTrafficPolicyInstance where
  toQuery = Prelude.const Prelude.mempty

-- | An empty element.
--
-- /See:/ 'newDeleteTrafficPolicyInstanceResponse' smart constructor.
data DeleteTrafficPolicyInstanceResponse = DeleteTrafficPolicyInstanceResponse'
  { -- | The response's http status code.
    httpStatus :: Prelude.Int
  }
  deriving (Prelude.Eq, Prelude.Read, Prelude.Show, Prelude.Generic)

-- |
-- Create a value of 'DeleteTrafficPolicyInstanceResponse' with all optional fields omitted.
--
-- Use <https://hackage.haskell.org/package/generic-lens generic-lens> or <https://hackage.haskell.org/package/optics optics> to modify other optional fields.
--
-- The following record fields are available, with the corresponding lenses provided
-- for backwards compatibility:
--
-- 'httpStatus', 'deleteTrafficPolicyInstanceResponse_httpStatus' - The response's http status code.
newDeleteTrafficPolicyInstanceResponse ::
  -- | 'httpStatus'
  Prelude.Int ->
  DeleteTrafficPolicyInstanceResponse
newDeleteTrafficPolicyInstanceResponse pHttpStatus_ =
  DeleteTrafficPolicyInstanceResponse'
    { httpStatus =
        pHttpStatus_
    }

-- | The response's http status code.
deleteTrafficPolicyInstanceResponse_httpStatus :: Lens.Lens' DeleteTrafficPolicyInstanceResponse Prelude.Int
deleteTrafficPolicyInstanceResponse_httpStatus = Lens.lens (\DeleteTrafficPolicyInstanceResponse' {httpStatus} -> httpStatus) (\s@DeleteTrafficPolicyInstanceResponse' {} a -> s {httpStatus = a} :: DeleteTrafficPolicyInstanceResponse)

instance
  Prelude.NFData
    DeleteTrafficPolicyInstanceResponse
  where
  rnf DeleteTrafficPolicyInstanceResponse' {..} =
    Prelude.rnf httpStatus
